@@ -104,6 +104,21 @@ function urlSecurityCheck(url, doc)
   }
 }
 
+function webPanelSecurityCheck(aSourceURL, aDestURL) {
+  var sourceURI = makeURL(aSourceURL);
+  var destURI = makeURL(aDestURL);
+
+  const nsIScriptSecurityManager = Components.interfaces.nsIScriptSecurityManager;
+  var secMan = Components.classes["@mozilla.org/scriptsecuritymanager;1"]
+                         .getService(nsIScriptSecurityManager);
+  try {
+    secMan.checkLoadURI(sourceURI, destURI, nsIScriptSecurityManager.STANDARD);
+  } catch (e) {
+    return false;
+  }
+  return true;
+}
+
 function isContentFrame(aFocusedWindow)
 {
   if (!aFocusedWindow)
@@ -366,14 +381,7 @@ function getTargetFile(aData, aSniffer, aContentType, aIsDocument, aSkipPrompt,
     fp.init(window, bundle.GetStringFromName(titleKey), 
             Components.interfaces.nsIFilePicker.modeSave);
     
-    var urlExt = null;
-    try {
-      var url = aSniffer.uri.QueryInterface(Components.interfaces.nsIURL);
-      urlExt = url.fileExtension;
-    }
-    catch (e) {
-    }
-    appendFiltersForContentType(fp, aContentType, urlExt,
+    appendFiltersForContentType(fp, aContentType, defaultExtension,
                                 aIsDocument ? MODE_COMPLETE : MODE_FILEONLY);  
   
     if (dir)
